@@ -1,7 +1,13 @@
 package Data::SearchEngine;
+BEGIN {
+  $Data::SearchEngine::VERSION = '0.21';
+}
 use Moose::Role;
 
-our $VERSION = '0.20';
+# ABSTRACT: A role for search engine abstraction.
+
+requires qw(search);
+
 
 has defaults => (
     traits => [ 'Hash' ],
@@ -13,17 +19,21 @@ has defaults => (
     }
 );
 
-requires qw(search);
 
 no Moose::Role;
 1;
 
 __END__
+=pod
 
 =head1 NAME
 
 Data::SearchEngine - A role for search engine abstraction.
 
+=head1 VERSION
+
+version 0.21
+
 =head1 SYNOPSIS
 
   package Data::SearchEngine::MySearch;
@@ -62,38 +72,44 @@ result will be an easily swappable backend with a common set of features.
 
 =head1 IMPLEMENTATION
 
-=head2 Step 1 - Extend the Query
+B<NOTE:> You should avoid adding new attributes or subclassing
+Data::SearchEngine classes unless otherwise noted. Doing so will break
+compatability with future releases and obviate the whole reason that
+Data::SearchEngine exists.  The only exception is the Results class (step 3
+below) which should B<only> be a subclass with roles applied, no new attributes
+or methods.
 
-If you have specific attributes that you need for your query, subclass the
-L<Data::SearchEngine::Query> object and add the attributes.  This part is
-optional.
+=head2 Step 1 - Wrap a search implementation
 
-=head2 Step 2 - Wrap a search implementation
+As shown in the SYNOPSIS, use the L<Data::SearchEngine> role in a class that
+wraps your search implementation.  Implement a C<search> method that takes a
+L<Data::SearchEngine::Query> object and returns a
+L<Data::SearchEngine::Results> object.
 
-Next use the L<Data::SearchEngine> role in a class that wraps your search
-implementation. You can find an example in L<Data::SearchEngine::Results>.
+=head2 Step 2 - Use Other Roles
 
-=head2 Step 3 - Profit!!!
+If your library includes functionality other than searching, such as indexing
+new documents or removing them, you may include the 
+L<Data::SearchEngine::Modifiable> role.  If you have other suggestions for
+roles please drop me a line!
 
-!!!
+=head2 Step 3 - Extend the Results
 
-=head1 ATTRIBUTES
+The results object may not have quite enough pieces for your implementation.
+If not, you can C<extend> L<Data::SearchEngine::Results> and add some other
+roles:
 
-=head2 defaults
+=over 4
 
-The C<defaults> attribute is a simple HashRef that backends may use to get
-default settings from the user.  The implementation of C<search> may then use
-these defaults when setting up instances of a search.
+=item Data::SearchEngine::Results::Faceted
 
-=head1 METHODS 
+For results that contain faceted data.
 
-=head2 get_default ($key)
+=item Data::SearchEngine::Results::Spellcheck
 
-Returns the value from C<defaults> (if any) for the specified key.
+For results that contain spellcheck data.
 
-=head2 set_default ($key, $value)
-
-Sets the value in C<defaults>.
+=back
 
 =head1 DIGESTS
 
@@ -103,17 +119,34 @@ a base64 MD5 digest to produce a unique key identifying this query.  You can
 then serialize the Result using L<MooseX::Storage> and store it under the
 digest of the Query for caching.
 
+=head1 ATTRIBUTES
+
+=head2 defaults
+
+The C<defaults> attribute is a simple HashRef that backends may use to get
+default settings from the user.  The implementation of C<search> may then use
+these defaults when setting up instances of a search.
+
+=head1 METHODS
+
+=head2 get_default ($key)
+
+Returns the value from C<defaults> (if any) for the specified key.
+
+=head2 set_default ($key, $value)
+
+Sets the value in C<defaults>.
+
 =head1 AUTHOR
 
-Cory G Watson, C<< <gphat at cpan.org> >>
+Cory G Watson <gphat@cpan.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Cory G Watson
+This software is copyright (c) 2011 by Cold Hard Code, LLC.
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-See http://dev.perl.org/licenses/ for more information.
+=cut
 
