@@ -1,20 +1,28 @@
 package Data::SearchEngine::Item;
+BEGIN {
+  $Data::SearchEngine::Item::VERSION = '0.21';
+}
 use Moose;
 use MooseX::Storage;
 
+# ABSTRACT: An individual search result.
+
 with 'MooseX::Storage::Deferred';
 
+
 has id => (
     is => 'rw',
     isa => 'Str'
 );
 
+
 has score => (
     is => 'rw',
     isa => 'Num',
     default => 0
 );
 
+
 has values => (
     traits  => [ 'Hash' ],
     is      => 'rw',
@@ -27,14 +35,21 @@ has values => (
     },
 );
 
+no Moose;
 __PACKAGE__->meta->make_immutable;
 
 1;
+__END__
+=pod
 
 =head1 NAME
 
 Data::SearchEngine::Item - An individual search result.
 
+=head1 VERSION
+
+version 0.21
+
 =head1 SYNOPSIS
 
   $result->add(Data::SearchEngine::Item->new(
@@ -57,14 +72,14 @@ HashRef.
 
 A unique identifier for this item.
 
-=head2 values
-
-The name value pairs for this item.
-
 =head2 score
 
 The score this item earned.
 
+=head2 values
+
+The name value pairs for this item.
+
 =head1 METHODS
 
 =head2 keys
@@ -82,14 +97,14 @@ Sets the value for the specified key for this item.
 
 =head1 AUTHOR
 
-Cory G Watson, C<< <gphat at cpan.org> >>
+Cory G Watson <gphat@cpan.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Cory G Watson
+This software is copyright (c) 2011 by Cold Hard Code, LLC.
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
 
-See http://dev.perl.org/licenses/ for more information.
\ No newline at end of file
