@@ -1,17 +1,28 @@
 package Data::SearchEngine::Modifiable;
+BEGIN {
+  $Data::SearchEngine::Modifiable::VERSION = '0.21';
+}
 use Moose::Role;
 
+# ABSTRACT: A role for search engines with an updateable index.
+
+
 requires qw(add present remove remove_by_id update);
 
 no Moose::Role;
 1;
 
+
 __END__
+=pod
 
 =head1 NAME
 
-Data::SearchEngine::Modifiable - A role for search engines with an updateable
-index.
+Data::SearchEngine::Modifiable - A role for search engines with an updateable index.
+
+=head1 VERSION
+
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -45,15 +56,14 @@ Updates the specified thing in the index.
 
 =head1 AUTHOR
 
-Cory G Watson, C<< <gphat at cpan.org> >>
+Cory G Watson <gphat@cpan.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Cory G Watson
+This software is copyright (c) 2011 by Cold Hard Code, LLC.
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-See http://dev.perl.org/licenses/ for more information.
+=cut
 
